light text library for 5110 nokia lcd * easy to modify * proportional font, bold / inverse modes * easy to add / change fonts * fixed rows for fast update

Library finished! :-) If you use 5110 and need fast menus - try this library. No overhead - small and robust, optimized for this display type only, fast update. Nice looking font. Power management. Displays from 5110 and 3110 are cheap as dirt :-)

Revision:
5:c37e5454bdb2
Parent:
4:82917c164f2b
Child:
6:cd44333c061b
--- a/medvdv5110.h	Mon Apr 08 07:18:52 2013 +0000
+++ b/medvdv5110.h	Fri Jan 31 20:25:57 2014 +0000
@@ -17,7 +17,7 @@
 } lcd5110font;
 
 // Contrast value depends of voltage and other factors 
-#define DEFAULT_CONTRAST 36
+#define DEFAULT_CONTRAST 30
 
 //
 // Nokia 5110 LCD Interface Class
@@ -54,7 +54,8 @@
 
     void Reset();                           // Reset LCD, configure defaults and contrast
     void Clear(char pattern = 0);           // Clear - fill all by 8bit line 'pattern'
-    void PowerOff();                        // LCD power off
+    void Power(bool power = true);         // LCD power off / wake up
+    void InverseMode(bool inverse = true);  // Inverse mode for all LCD
 
     void Contrast(char contrast = DEFAULT_CONTRAST );    // Change contrast